Global variance computation for a set of locations using the covarianve model
globalvar(geodata, locations, coords = geodata$coords, krige)An scalar with the value of the global variance
an object of the class geodata
n by 2 matrix with a set of locations, typically a prediction grid
data coordinates
a list defining the model components and the type of
kriging. It can take an output to a call to krige.control or
a list with elements as for the arguments in krige.control.
Paulo Justiniano Ribeiro Jr. [email protected],
Peter J. Diggle [email protected].
Isaaks, E.S and Srivastava, R.M. (1989) An Introduction to Applied Geostatistics, pag. 508, eq. 20.7. Oxford University Press.
krige.conv for the kriging algorithm.