grf(n, grid = "irreg", nx = round(sqrt(n)), ny = round(sqrt(n)),
xlims = c(0, 1), ylims = c(0, 1), nsim = 1,
cov.model = c("exponential", "matern", "gaussian",
"spherical", "circular", "cubic", "wave",
"powered.exponential", "cauchy", "gneiting",
"gneiting.matern", "pure.nugget"),
cov.pars = stop("cov. parameters (sigmasq and phi) needed"),
kappa = 0.5, nugget = 0, lambda = 1, aniso.pars,
method = c("cholesky", "svd", "eigen", "circular.embedding"),
messages.screen = TRUE)cov.spatial for
further details. Defaults
to "exponential"."matern", "powered.exponential", "gneiting"
and "gneiting.matern". More details on the documentation DETAILS below.TRUE.nsim = 1) or a matrix with the
simulated values. For the latter each column corresponds to one
simulation."cholesky", "svd" and "eigen" the
simulation consists of multiplying a vector of standardized
normal deviates by a square root of the covariance matrix.
The square root of a matrix is not uniquely defined. The
three available methods differs in the way they compute the
square root of the (positive definite) covariance matrix. For method = "circular.embedding" the algorithm implements
the method described by Wood & Chan (1994) which is based on Fourier
transforms.
Only regular and equally spaced grids can be generated using this method.
The code for the "circular.embedding" method
was provided by Martin Schlather, University of Bayreuth
("circular.embedding" method is
no longer being maintained. Martin will soon release a
package for unconditional simulation of random fields. This will be
announced on the R(contributed packages) and geoR home page.
When this new package is released the current implementation
of the "circular.embedding" method might become obsolete.
plot.grf and image.grf for
graphical output,
coords.aniso for anisotropy coordinates transformation
and, chol,
svd and eigen for methods of matrix decomposition.# initial value for the random numbers generator (if needed)
if(is.R()) .Random.seed <- 1:3
#
sim1 <- grf(100, cov.pars=c(1, .25))
# a display of simulated locations and values
points.geodata(sim1)
# empirical and theoretical variograms
plot(sim1)
#
# a "smallish" simulation
sim2 <- grf(441, grid="reg", cov.pars=c(1, .25))
image.grf(sim2)
#
# a "bigger" one
sim3 <- grf(40401, grid="reg", cov.pars=c(10, .2), met="circ")
image.grf(sim3)Run the code above in your browser using DataLab