Learn R Programming

geoR (version 1.0-8)

lines.krige.bayes: Add a (Bayesian) Estimated Variogram to a Plot

Description

Adds a estimated variogram to a plot with an empirical variogram. The estimate is a chosen summary (mean, mode or mean) of the posterior distribution returned by the function krige.bayes.

Usage

lines.krige.bayes(obj, max.dist,
             summary.posterior = c("mode", "median", "mean"), ...)

Arguments

obj
an object of the class krige.bayes, typically output of the function krige.bayes.
max.dist
maximum distance for the x-axis.
summary.posterior
specify which summary of the posterior distribution should be used as parameter estimation. Options are "mean", "median" or "mode".
...
arguments to be passed to the function lines.

Value

  • A line with the estimated variogram plot is added to the plot in the current graphics device. No values are returned.

References

Further information about geoR can be found at: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html.

See Also

krige.bayes and lines.

Examples

Run this code
#See examples in the documentation of the function krige.bayes().

Run the code above in your browser using DataLab