Learn R Programming

geoR (version 1.0-0)

lines.variogram.envelope: Adds Envelopes Lines to a Variogram Plot

Description

Variogram envelopes computed by variog.model.env or variog.mc.env are added to the current variogram plot.

Usage

lines.variogram.envelope(obj, lty = 3, ...)

Arguments

obj
an object of the class "variogram.envelope", typically an output of the functions variog.model.env or variog.mc.env.
lty
line type. Defaults to 3.
...
arguments to be passed to the function lines.

Value

  • Lines defining the variogram envelope are added to the plotin the current graphics device.

References

Further information about geoR can be found at: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html.

See Also

variog for variogram computation, variog.model.env and variog.mc.env for computation of variogram envelopes, and lines for the generic function.

Examples

Run this code
if(is.R()) data(s100)
s100.vario <- variog(s100, max.dist = 1)
s100.ml <- likfit(s100, ini=c(.5, .5))
s100.mod.env <- variog.model.env(s100, obj.variog = s100.vario,
   model = s100.ml) 
s100.mc.env <- variog.mc.env(s100, obj.variog = s100.vario)
plot(s100.vario)
lines(s100.mod.env)
lines(s100.mc.env, lwd=2)

Run the code above in your browser using DataLab