Learn R Programming

geoR (version 1.0-0)

summary.variomodel: Summarize Results of Variogram Estimation

Description

This function prints a summary of the parameter estimation results given by olsfit or wlsfit.

Usage

summary.variomodel(obj)

Arguments

obj
an object of the class "variomodel" typically an output of olsfit or wlsfit.

Value

  • Prints a summary of the estimation results on the screen or other output device.

References

Further information about geoR can be found at: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html.

See Also

The functions olsfit and wlsfit for variogram based estimation. For likelihood based parameter estimation see likfit.

Examples

Run this code
if(is.R()) data(s100)
s100.vario <- variog(s100, max.dist=1)
wls <- wlsfit(s100.vario, ini=c(.5, .5), fix.nugget = TRUE)
wls
summary(wls)

Run the code above in your browser using DataLab