Learn R Programming

geoR (version 1.0-8)

variog4: Computes Directional Variograms

Description

Computes directional variograms for 4 directions provided by the user.

Usage

variog4(geodata, coords = geodata$coords, data = geodata$data,
        uvec = "default", trend = "cte", lambda = 1,
        option = c("bin", "cloud", "smooth"),
        estimator.type = c("classical", "modulus"),
        nugget.tolerance = 0, max.dist = NULL, pairs.min = 2,
        bin.cloud = FALSE, direction = c(0, pi/4, pi/2, 3*pi/4),
        tolerance = pi/8, unit.angle = c("radians", "degrees"),
        messages.screen = TRUE, ...)

Arguments

direction
a vector with values of 4 angles, indicating the directions for which the variograms will be computed. Defaults to c(0, 45, 90, 135) (degrees).

Value

  • The output is an object of the class variog4, a list with five components. The first four elements are estimated variograms for the directions provided and the last is the omnidirectional variogram. Each individual component is an object of the class variogram, an output of the function variog.

References

Further information about geoR can be found at: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html.

See Also

variog for variogram calculations and plot.variog4 for plotting results

Examples

Run this code
if(is.R()) data(s100)
var4 <- variog4(s100, max.dist=1)
plot(var4)

Run the code above in your browser using DataLab