Learn R Programming

geoR (version 1.0-0)

wrappers: Wrappers for the C functions used in geoR

Description

These functions are wrappers for some, but no tall, the C functions included in the geoR package. Typically the C code is directly called from the geoR functions but these functions allows independent calls.

Usage

distdiag(coords)
loccoords(coords, locations)
diagquadraticformXAX(X, lowerA, diagA) 
bilinearform(X, lowerA, diagA, Y)

Arguments

coords
an $n \times 2$ matrix with the data coordinates.
locations
an $n \times 2$ matrix with the coordinates of the prediction locations.
lowerA
a vector with the diagonal terms of the symmetric matrix A.
diagA
a vector with the diagonal terms of the symmetric matrix A.
X
a matrix with conforming dimensions.
Y
a matrix with conforming dimensions.

Value

  • The outputs are:
    • loccoords
    {returns a vector with distances between data points and prediction locations. }
  • distdiagreturns a vector with distances between data locations, including the diagonal zero values.
  • diagquadraticformXAXreturns a vector with the diagonal term of the quadratic form $X' A X$.
  • bilinearformreturns a vector or a matrix with the terms of the quadratic form $X' A Y$.

References

Further information about geoR can be found at: http://www.maths.lancs.ac.uk/~ribeiro/geoR.html.