Usage
xvalid(geodata, coords = geodata$coords, data = geodata$data,
model, reestimate = FALSE, variog.obj = NULL,
output.reestimate = FALSE, locations.xvalid = "all",
data.xvalid = NULL, messages.screen = TRUE, ...)Arguments
geodata
a list containing element coords
as described next. Typically an object of the class
"geodata" - a geoR data-set.
If not provided the arguments
coords must be provided instead.
coords
an $n \times 2$ matrix containing
coordinates of the $n$ data locations in each row.
Defaults to geodata$coords, if provided.
data
a vector or matrix with data values.
If a matrix is provided, each column is regarded as one variable or realization.
Defaults to geodata$data, if provided.
model
an object containing information on a fitted
model. Typically an output of likfit,
variofit. reestimate
logical. Indicates whether or not the model
parameters should be re-estimated for each point removed from the data-set.
variog.obj
on object with the empirical variogram, typically an
output of the function variog. Only used if
reestimate = TRUE and the object passed to the argument
model is the re output.reestimate
logical. Only valid if reestimate =
TRUE. Specifies whether the re-estimated parameters are returned.
locations.xvalid
there are three possible specifications for
this argument: "all" indicates the leaving-on-out
method is used. The second possibility is to use only a sub-set of
the data for cross-validation. For this case a vector shoul
data.xvalid
data values at the validation locations.
Only used if the validation locations are not the same or a
subset of the original data coordinates.
messages.screen
logical. Indicates whether
status messages should be printed on the screen (or output device)
while the function is running.
...
further arguments to the minimization functions used by likfit,
variofit.