class "geodata".
Objects of the class "geodata" are lists with two obligatory
components, coords and data. Optional components are
allowed and a typical example is a vector or matrix with values
of the covariate(s).as.geodata(obj, coords.col = 1:2, data.col = 3, data.names = NULL,
covar.col = NULL, covar.names = "obj.names",
realisations = NULL,
na.action = c("ifany", "ifdata", "ifcovar", "none"),
rep.data.action, rep.covar.action)obj with the
realisation indicator variable.
See DETAILS below.NA's. The default option "ifany" excludes all points
for which there are NA's in the data or covariates. The option "ifdata" excludes points
"none"
keeps the repeated locations, if any. The option "first" retains
only the first data rep.data.locations, to be applied to
the covariates, if any. Defaults to
the same option set for rep.data.locations.class "geodata" which is a list
with two obligatory components (coords and data)
and other optional components:"geodata" contain data for
geostatistical analysis using the package geoR.
Storing data in this format facilitates the usage of the functions in geoR.
However, conversion of objects to this class is not obligatory
to carry out the analysis. Realisations
Tipically geostatistical data correspond to a unique realisation of
the spatial process.
However, sometimes different "realisations" are possible.
For instance, if data are collected in the same area at different
points in time and independence between time points is assumed,
each time can be considered a different "replicate" or "realisation"
of the same process. The argument realisations takes a vector
indication the replication number and can be passed to other geoR
functions as, for instance, likfit.
The data format is similar to the usual geodata format in
geoR.
Suppose there are realisations (times) $1, \ldots, J$
and for each realisations $n_1, ..., n_j$ observations are available.
The coordinates for different realisations
should be combined in a single $n \times 2$ object,
where $n=n_1 + \ldots + n_J$.
Similarly for the data vector and covariates (if any).
read.geodata for reading data from an
ASCII file and list for general information on lists.