Learn R Programming

geoR (version 1.6-5)

globalvar: ~~function to do ... ~~

Description

~~ A concise (1-5 lines) description of what the function does. ~~

Usage

globalvar(geodata, locations, coords = geodata$coords, krige)

Arguments

geodata
~~Describe geodata here~~
locations
coords
~~Describe coords here~~
krige
a list defining the model components and the type of kriging. It can take an output to a call to krige.control or a list with elements as for the arguments in krige.control. More details in the documention for

Value

  • ~Describe the value returned If it is a LIST, use
  • comp1Description of 'comp1'
  • comp2Description of 'comp2'
  • ...

Details

~~ If necessary, more details than the description above ~~

References

Isaaks, E.S and Srivastava, R.M. (1989) An Introduction to Applied Geostatistics, pag. 508, eq. 20.7. Oxford University Press.

See Also

krige.conv for the kriging algorithm.

Examples

Run this code
data(s100)

Run the code above in your browser using DataLab