likfit and it
will be made obsolete.likfit(geodata, coords=geodata$coords, data=geodata$data,
trend = "cte", ini, fix.nugget = FALSE, nugget = 0,
cov.model = c("exponential", "matern", "gaussian",
"spherical", "circular", "cubic", "wave",
"powered.exponential", "cauchy", "gneiting",
"gneiting.matern", "pure.nugget"),
kappa = 0.5, fix.lambda = TRUE, lambda = 1, method = "ML",
predicted = FALSE, residuals = FALSE,
minimisation.function = c("optim","nlmP", "nlm"),
automatic.refit = FALSE, range.limits,
messages.screen = TRUE, ...)coords and
data as described next. If not provided the arguments
coords and data must be provided instead.coords of the argument geodata.data of the argument geodata."cte" (constant mean - the default option), "1st" (a first degree polynomial
on the coordinates), "2nd" (a second degree polynomial
on the coordinateini should be fix.nugget = T the
argument ini must be a vector of length 2 or a matrix with 2 columnsfix.nugget =
TRUE. Defaults to zero.cov.spatial."matern", "powered.exponential",
"gneiting"
or "gneiting.matern"). For more details see documentatiTRUE, the default, the transformation
parameter is regarded as fixed (known) during the estimation
process, otherwise the ML/REML for this parameter is also computed."ML" defines maximum likelihood and "REML"
defines restricted maximum likelihood. Defaults to "ML".FALSE. If set to TRUE
the model is automatically changed and re-fitted in the following cases:
"optim", the default, "nlmP" and "nlm".c(0, +Inf).control type arguments which controls the
behavior of the minimization algorithm. For further details see
documentation for the minimization functions.variomodel which is a list with the following components:fix.nugget = FALSE or the fixed
(known) value if fix.nugget = TRUE.fix.lambda = TRUE or the estimated value if fix.lambda = FALSE.likfit.old()."ML" (maximum likelihood)
or "REML" (restricted maximum likelihood).predicted = TRUE or
residuals = TRUE.predicted = TRUE.residuals = TRUE.likfit.old().summary.variomodel,
plot.variogram,
lines.variogram,
and lines.variomodel for graphical output.
Profile likelihoods can be computed by proflik.
olsfit and
wlsfit performs variogram based estimation while
krige.bayes performs Bayesian inference.
For details about the minimization functions see the documentation for
optim and nlm.if(is.R()) data(s100)
ml <- likfit(s100, ini=c(.5, .5), fix.nug=T)
summary(ml)
reml <- likfit(s100, ini=c(.5, .5), fix.nug=T, met="REML")
summary(reml)
plot(variog(s100))
lines(ml)
lines(reml, lty=2)Run the code above in your browser using DataLab