predict.BGCCM: Prediction for the bivariate Gaussian common component
geostatistical model
Description
Performs prediction for the bivariate Gaussian common component
geostatistical model
Usage
# S3 method for BGCCM
predict(object, locations, borders,
variable.to.predict = 1, ...)Arguments
object
on object of the class BGCCMfit, which is
an output of likfitBGCCM.
locations
an \(N \times 2\) matrix or data-frame with
the 2-D coordinates of the \(N\) prediction locations,
or a list for which
the first two components are used. Input is internally checked by the
function check.locations.
borders
optional. If missing, by default reads the element
borders of the geodata object of the variable to be
predicted. Ignored if set to NULL.
If a two column matrix defining a polygon is
provided the prediction is performed only at locations inside this polygon.
variable.to.predict
scalar with options for values or 2
indicating which variable is to be predicted.
Value
A list of the class BGCCMpred with components:
predictedpredicted values.
krige.varprediction variances.
Warning
This is a new function and still in draft format and pretty much untested.
Examples
Run this code# NOT RUN {
# see http://www.leg.ufpr.br/geoR/tutorials/CCM.R
# }
Run the code above in your browser using DataLab