an object of classlikGRF, typically
a result of a call to likfit.
...
extra arguments for print. A commonly used
argument is digits which
specifies the number of digits for the numerical output.
The default is given by options()$digits.
Value
print.likGRF prints the parameter estimates and the value of the
maximized likelihood.
summary.likGRF returns a list with main results of a call to
likfit.
print.summary.likGRF prints these results on the screen (or other
output device) in a "nice" way.
Details
A detailed summary of a object of the class likGRF is produced by
by summary.likGRF and printed by print.summary.likGRF.
This includes model specification with values of fixed and estimated parameters.
A simplified summary of the parameter estimation is printed by
print.likGRF.
References
Further information about geoR can be found at:
http://www.maths.lancs.ac.uk/~ribeiro/geoR.html.