likfit.
Functions are methods for summary and
print for the classes likGRF and summary.likGRF.## S3 method for class 'likGRF':
summary(object, \dots)
## S3 method for class 'likGRF':
print(x, digits = max(3, getOption("digits") - 3), ...)
## S3 method for class 'summary.likGRF':
print(x, digits = max(3, getOption("digits") - 3), ...)print.print.likGRF prints the parameter estimates and the value of the
maximized likelihood.
summary.likGRF returns a list with main results of a call to
likfit.
print.summary.likGRF prints these results on the screen (or other
output device) in a "nice" format.likGRF is produced by
by summary.likGRF and printed by print.summary.likGRF.
This includes model specification with values of fixed and estimated parameters.
A simplified summary of the parameter estimation is printed by
print.likGRF.likfit, print,
summary.# See examples for the function likfit()Run the code above in your browser using DataLab