Learn R Programming

geoR (version 1.7-5.2.1)

summary.variofit: Summarize Results of Variogram Estimation

Description

This function prints a summary of the parameter estimation results given by variofit.

Usage

# S3 method for variofit
summary(object, …)

Arguments

object

an object of the class "variomodel" typically an output of variofit.

…

other arguments to be passed to the function print or summary.

Value

Prints a summary of the estimation results on the screen or other output device.

References

Further information on the package geoR can be found at: http://www.leg.ufpr.br/geoR.

See Also

The functions variofit for variogram based estimation. For likelihood based parameter estimation see likfit.

Examples

Run this code
# NOT RUN {
s100.vario <- variog(s100, max.dist=1)
wls <- variofit(s100.vario, ini=c(.5, .5), fix.nugget = TRUE)
wls
summary(wls)
# }

Run the code above in your browser using DataLab